//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//						(c) 1997 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	Lightcurve.h --- lightcurve class
//
//	DESCRIPTION:
//		Lightcurve
//
//	CHANGE HISTORY:
//		AI, 2007-05-30: 1.0.0: - first version
//
//	AUTHOR:
//		A. Ibarra, Wed May 30 16:32:18 GMT 2007
//
//	REFERENCES:
//
//
//

#ifndef LIGHTCURVE_H_
#define LIGHTCURVE_H_

#include "Dal.h"
#include <valarray>
#include <map>
#include <vector>

#include "LccorrUtils.h"

class Lightcurve {

public:
	Lightcurve(double binSize);
	Lightcurve(double binSize,int ccdNr);
	~Lightcurve() {}
	void setTimeLimits(const Column * col);
	void setTimeLimits(const Column * startCol,const Column * stopCol);
	void setTimeLimits(double startTime, double endTime);
	vector<double> getTimeLimits();

	void createTimeGrid();

    void createLc();

	void setExposuInfo(const Table *tab, const Table *gtiTab, const Column *col);

	void setArea(double area);
	double getArea();

	int getCcdNr();
	double getTotalCounts();

	void accumCounts();
	void correctBackScale(Lightcurve *srcLc);

	void calculateErrors();

	void showInfo();
	void showCCDInfo();

	void add(Lightcurve *lc);
	void substract(Lightcurve *lc);

	void createFile(std::string fileName,bool isSrc,bool isBkgApplied);
	void setDefaultKeywords(std::vector<std::vector<std::string> >  tmpFileNames);
	void printToFile(string fileName);

	void copyBkgInfo(Lightcurve *bkgLc);
	void calculateWeightedBackScale(Lightcurve *bkgLc);


private:
	void getRange(const Column *col);
	int _ccdNr;

	std::vector<std::string> defAttributes;

	double _startTime;
	double _endTime;
	double _binSize;

	valarray<double> _counts;
	valarray<double> _errCounts;
	valarray<double> _realCounts;
	double _totalCounts;
	valarray<double> _countRate;
	valarray<double> _errCountRate;
	valarray<double> _fracExp;
	valarray<double> _timeGrid;
	map<double,int> _expoCountMap;
	map<double,vector<double> > _expoGtiMap;
	map<double,double> _expoTimeDelMap;
	LccorrUtils _lcUtils;
	double _numberLcAdded;

	double _area;

	vector<double> _totalCCDCounts;
	vector<double> _ccdArea;
	double _backScale;
	double _backScaleWeighted;

};

#endif /*LIGHTCURVE_H_*/
